import utils
import json
import sys
import dateutil.parser
import file2jsonTest
import logging

logfile="metadata_to_json_fast.log"

def loadtext(record_key):
    filename = file2jsonTest.getFileName(record_key)
    pagecontent = file2jsonTest.file2Json(filename)
    return pagecontent

if len(sys.argv) != 3:
    print('Expecting two arguments: min id (inclusive) and max id (exclusive)')
    exit()

min_id = int(sys.argv[1])
max_id = int(sys.argv[2])

assert (min_id >= 0) and (max_id >= 0)
assert min_id < max_id

formatter_str = '%(asctime)s - %(name)s - %(levelname)s - %(message)s'
log_level = logging.INFO
logging.basicConfig(filename=logfile, format=formatter_str, level=log_level)
logger = logging.getLogger(__name__)

#print('Processing ids %d (inclusive) up to %d (exclusive)...' % (min_id, max_id))

mydb = utils.connect_db()
cursor = mydb.cursor()
cursor.execute('SET CHARACTER SET utf8mb4')

cursor.execute('SET GLOBAL connect_timeout=28800')
cursor.execute('SET GLOBAL wait_timeout=28800')
cursor.execute('SET GLOBAL interactive_timeout=28800')
cursor.execute('SET GLOBAL max_allowed_packet=67108864')

# Get record keys
query = "SELECT id, record_key FROM idl_doc WHERE id>=%s AND id<%s AND industry_id = 2"
cursor.execute(query, (min_id, max_id))
results = cursor.fetchall()
id_to_record_key = {}
for id, record_key in results:
    id_to_record_key[id] = record_key

query = "SELECT id, itag, value FROM idl_doc_field WHERE id>=%s AND id<%s AND value='deposition' ORDER BY id"

cursor.execute(query, (min_id, max_id))

entries = cursor.fetchall()
assert len(entries) > 0

#print(entries)  # For debugging

i = 0  # Index in the entries list

while i < len(entries):
    if entries[i][0] not in id_to_record_key:
        i += 1
        continue

    record_key = id_to_record_key[entries[i][0]]
    inner_obj = {}
    inner_obj['_index'] = 'tobaccodep'
    inner_obj['_id'] = record_key
    outer_obj = {}
    outer_obj['index'] = inner_obj
    print(json.dumps(outer_obj))

    url = "https://s3-us-west-2.amazonaws.com/edu.ucsf.library.iddl.artifacts/%s/%s/%s/%s/%s/%s.pdf" % (record_key[0], record_key[1], record_key[2], record_key[3], record_key, record_key)

    j = i
    while (j < len(entries)) and (entries[j][0] == entries[i][0]):
        j += 1

    sys.stdout.write('{"url": ')
    sys.stdout.write('\"' + url + '\"')

    while i < j:
        itag_str = str(entries[i][1])
        value_str = str(entries[i][2])
        desc = utils.itag_desc[itag_str]
        if "Date" in desc:
            try:
                value_str = str(dateutil.parser.parse(value_str))
                value_str = value_str.replace(' 00:00:00', '')
            except ValueError:
                value_str = "1970-01-01"
        sys.stdout.write(', ')
        sys.stdout.write('\"' + desc + '\"')
        sys.stdout.write(': ')
	if desc in ("Attached_Artifacts","Journal_Citation"):
            sys.stdout.write(value_str)
        else:
	    value_str = value_str.replace('\\',' ')
            value_str = value_str.replace('"','\\"')
            sys.stdout.write('\"' + value_str + '\"')
        i += 1
    data = json.dumps(loadtext(record_key))
    data = data[1:-1]
    if "text_content" in data:
        sys.stdout.write(', ')
        sys.stdout.write(data)
    print('}')
print('')

